function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent } from 'react';
import { MapboxConsumer } from './Mapbox';

class Marker extends PureComponent {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      position: {
        x: 0,
        y: 0
      }
    });

    _defineProperty(this, "handleUpdatePosition", () => {
      if (!window.mapboxgl) return;
      const mapboxInstance = this.props.mapboxInstance;
      const point = mapboxInstance.project(window.mapboxgl.LngLat.convert([this.props.lng, this.props.lat]));
      this.setState({
        position: {
          x: point.x.toFixed(0),
          y: point.y.toFixed(0)
        }
      });
    });

    _defineProperty(this, "marker", null);
  }

  componentDidMount() {
    this.props.mapboxInstance.on('move', this.handleUpdatePosition);
    this.handleUpdatePosition();
  }

  componentDidUpdate(prevProps) {
    if (prevProps.lat !== this.props.lat || prevProps.lng !== this.props.lng) {
      this.handleUpdatePosition();
    }
  }

  componentWillUnmount() {
    this.props.mapboxInstance.off('move', this.handleUpdatePosition);
  }

  render() {
    return React.createElement("div", {
      className: "mapboxgl-marker",
      style: {
        transform: `translate(${this.state.position.x}px, ${this.state.position.y}px) translate(0px, 0px) translate(-50%, -100%)`,
        WebkitBackfaceVisibility: 'hidden',
        zIndex: 1
      }
    }, this.props.children);
  }

}

const MarkerWithConsumer = props => React.createElement(MapboxConsumer, null, React.createElement(Marker, props));

export default MarkerWithConsumer;